<?php

namespace Drupal\entity_router\Event;

use Symfony\Contracts\EventDispatcher\Event;
use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * The event to dispatch for notifying about entity response.
 */
class EntityResponseEvent extends Event {

  /**
   * The name of the event.
   */
  public const NAME = 'entity_router.response';

  /**
   * Constructs the event.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The inbound HTTP request.
   * @param \Symfony\Component\HttpFoundation\Response $response
   *   The response to send.
   * @param \Drupal\Core\Entity\EntityInterface|null $entity
   *   The requested entity.
   */
  public function __construct(
    public readonly Request $request,
    public readonly Response $response,
    public readonly ?EntityInterface $entity,
  ) {
  }

  /**
   * {@inheritdoc}
   *
   * @deprecated Use public property.
   */
  public function getRequest(): Request {
    @\trigger_error(__METHOD__ . '() is deprecated in entity_router:3.0.0 and will be removed in entity_router:4.0.0', \E_USER_DEPRECATED);
    return $this->request;
  }

  /**
   * {@inheritdoc}
   *
   * @deprecated Use public property.
   */
  public function getResponse(): Response {
    @\trigger_error(__METHOD__ . '() is deprecated in entity_router:3.0.0 and will be removed in entity_router:4.0.0', \E_USER_DEPRECATED);
    return $this->response;
  }

  /**
   * {@inheritdoc}
   *
   * @deprecated Use public property.
   */
  public function getEntity(): ?EntityInterface {
    @\trigger_error(__METHOD__ . '() is deprecated in entity_router:3.0.0 and will be removed in entity_router:4.0.0', \E_USER_DEPRECATED);
    return $this->entity;
  }

}
